@@ -6,4 +6,7 @@ library("testthat")
 library("quanteda.textstats")
 quanteda::quanteda_options(reset = TRUE)
 
+# return an error for all Matrix deprecations
+options(Matrix.warnDeprecatedCoerce = 2)
+
 test_check("quanteda.textstats")
